﻿// Sample Code is provided for the purpose of illustration only and is not intended to be used in a production environment. 
// THIS SAMPLE CODE AND ANY RELATED INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
// EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY 
// AND/OR FITNESS FOR A PARTICULAR PURPOSE

namespace HardwareApiCSharpSample
{
    using System;
    using System.Globalization;
    using System.Net.Http;
    using System.Threading.Tasks;

    public class MetadataSample
    {
        private ClientConfiguration _clientConfiguration;

        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="c">An instance of ClientConfiguration that contains all parameters populated</param>
        public MetadataSample(ClientConfiguration clientConfiguration)
        {
            this._clientConfiguration = clientConfiguration;
        }

        public void RunMetadataDownloadSample()
        {
            // **********************
            //       SETTINGS
            // **********************
            var productId = this._clientConfiguration.ProductId;
            var submissionId = this._clientConfiguration.SubmissionId;
            var shippingLabelId = this._clientConfiguration.ShippingLabelId;

            var clientId = this._clientConfiguration.ClientId;
            var clientSecret = this._clientConfiguration.ClientSecret;
            var serviceEndpoint = this._clientConfiguration.ServiceUrl;
            var tokenEndpoint = this._clientConfiguration.TokenEndpoint;

            // Get authorization token
            Console.WriteLine("Getting authorization token ");
            var accessToken = HardwareIngestionClient.GetClientCredentialAccessTokenAsync(
                tokenEndpoint,
                clientId,
                clientSecret).Result;

            // create ingestion client
            var client = new HardwareIngestionClient(accessToken, serviceEndpoint);

            // Get submission and extract metadata
            dynamic submission = client.Invoke<dynamic>(
                HttpMethod.Get,
                relativeUrl: string.Format(
                    CultureInfo.InvariantCulture,
                    HardwareIngestionClient.GetSubmissionUrlTemplate,
                    HardwareIngestionClient.Version,
                    HardwareIngestionClient.Tenant,
                    productId,
                    submissionId),
                requestContent: null).Result;

            Console.WriteLine("Retrieved submission.......\n\n");
            Console.WriteLine(submission.ToString());

            // Get the metadata download URL
            string metadataUrl = string.Empty;

            // NOTE: Since the sample uses dynamic type - using foreach to findout drivermetdata item.
            // you are recommended to use other options in a statically typed fashion - like linq/lambda expressions etc
            foreach (var downloadItem in submission.downloads.items)
            {
                if (downloadItem.type == "driverMetadata")
                {
                    metadataUrl = downloadItem.url;
                }
            }

            if (!string.IsNullOrWhiteSpace(metadataUrl))
            {
                // TODO: change the fileName and download path as appropriate
                HardwareIngestionClient.DownloadFile(@"E:\test\mydrivermetadata.json", metadataUrl);
            }
        }
    }
}
