﻿
// Sample Code is provided for the purpose of illustration only and is not intended to be used in a production environment. 
// THIS SAMPLE CODE AND ANY RELATED INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
// EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY 
// AND/OR FITNESS FOR A PARTICULAR PURPOSE

namespace HardwareApiCSharpSample.Models
{
    using Newtonsoft.Json;
    using Newtonsoft.Json.Converters;
    using System;
    using System.Collections.Generic;

    public class Product
    {
        /// <summary>
        /// Gets or sets announcement date.
        /// </summary>
        public DateTime? AnnouncementDate { get; set; }

        /// <summary>
        /// Gets or sets device metadata category.
        /// </summary>
        public string DeviceMetadataCategory { get; set; }

        /// <summary>
        /// Gets or sets device metadata ids.
        /// </summary>
        public IList<Guid> DeviceMetadataIds { get; set; }

        /// <summary>
        /// Gets or sets firmware version.
        /// </summary>
        public string FirmwareVersion { get; set; }

        /// <summary>
        /// Gets or sets device type.
        /// </summary>
        [JsonConverter(typeof(StringEnumConverter))]
        public DeviceType DeviceType { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether the driver must  be test signed.
        /// </summary>
        public bool IsTestSign { get; set; }

        /// <summary>
        /// Gets or sets marketing names.
        /// </summary>
        public IList<string> MarketingNames { get; set; }

        /// <summary>
        /// Gets or sets product name.
        /// </summary>
        public string ProductName { get; set; }

        /// <summary>
        /// Gets or sets the selected product types.
        /// </summary>
        public IDictionary<string, string> SelectedProductTypes { get; set; }

        /// <summary>
        /// Gets or sets requested signatures
        /// </summary>
        public IList<string> RequestedSignatures { get; set; }

        /// <summary>
        /// Gets or sets additional attributes
        /// </summary>
        public AdditionalAttributes AdditionalAttributes { get; set; }

        /// <summary>
        /// Gets or sets type of the package for this product
        /// </summary>
        [JsonConverter(typeof(StringEnumConverter))]
        public TestHarness TestHarness { get; set; }
    }
}
